@@ -12,7 +12,7 @@ class PyTwoFaas():
     print "It got here"
     payload = { 'userID' : clientId, 'compTK': self.cToken, 'userNum': phoneNum }
     print "Here"
-    import pdb; pdb.set_trace
+    import pdb; pdb.set_trace()
     r = requests.post(self.url + "/init", data=payload)
     print "There"
     print(r.text)
